OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Tasks" : "Aufgaben",
    "Personal" : "Persönlich",
    "{actor} created calendar {calendar}" : "{actor} hat den Kalender {calendar} erstellt",
    "You created calendar {calendar}" : "Sie haben den Kalender {calendar} erstellt",
    "{actor} deleted calendar {calendar}" : "{actor} hat den Kalender {calendar} gelöscht",
    "You deleted calendar {calendar}" : "Sie haben den Kalender {calendar} gelöscht",
    "{actor} updated calendar {calendar}" : "{actor} hat den Kalender {calendar} aktualisiert",
    "You updated calendar {calendar}" : "Sie haben hat den Kalender {calendar} aktualisiert",
    "{actor} restored calendar {calendar}" : "{actor} hat den Kalender {calendar} wiederhergestellt",
    "You restored calendar {calendar}" : "Sie haben den Kalender {calendar} wiederhergestellt",
    "You shared calendar {calendar} as public link" : "Sie haben den Kalender {calendar} als öffentlichen Link geteilt",
    "You removed public link for calendar {calendar}" : "Sie haben den öffentlichen Link für Kalender {calendar} entfernt",
    "{actor} shared calendar {calendar} with you" : "{actor} hat den Kalender {calendar} mit Ihnen geteilt",
    "You shared calendar {calendar} with {user}" : "Sie haben den Kalender {calendar} mit {user} geteilt",
    "{actor} shared calendar {calendar} with {user}" : "{actor} hat den Kalender {calendar} mit {user} geteilt",
    "{actor} unshared calendar {calendar} from you" : "{actor} teilt den Kalender {calendar} nicht mehr mit Ihnen",
    "You unshared calendar {calendar} from {user}" : "Sie teilen den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} teilt den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} teilt den Kalender {calendar} nicht mehr mit sich selbst",
    "You shared calendar {calendar} with group {group}" : "Sie haben den Kalender {calendar} mit der Gruppe {group} geteilt",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} teilt den Kalender {calendar} mit der Gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Sie teilen den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} teilt den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "Untitled event" : "Unbenannter Termin",
    "{actor} created event {event} in calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} erstellt",
    "You created event {event} in calendar {calendar}" : "Sie haben den Termin {event} im Kalender {calendar} erstellt",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} gelöscht",
    "You deleted event {event} from calendar {calendar}" : "Sie haben den Termin {event} im Kalender {calendar} gelöscht",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} aktualisiert",
    "You updated event {event} in calendar {calendar}" : "Sie haben den Termin {event} im Kalender {calendar} aktualisiert",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} hat den Termin {event} vom Kalender {sourceCalendar} in den Kalender {targetCalendar} verschoben",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Sie haben den Termin {event} vom Kalender {sourceCalendar} in den Kalender {targetCalendar} verschoben",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} wiederhergestellt",
    "You restored event {event} of calendar {calendar}" : "Sie haben den Termin {event} im Kalender {calendar} wiederhergestellt",
    "Busy" : "Beschäftigt",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erstellt",
    "You created to-do {todo} in list {calendar}" : "Sie haben eine Aufgabe {todo} in der Liste {calendar} erstellt",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} hat die Aufgabe {todo} aus der Liste {calendar} gelöscht",
    "You deleted to-do {todo} from list {calendar}" : "Sie haben die Aufgabe {todo} aus der Liste {calendar} gelöscht",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "You updated to-do {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erledigt",
    "You solved to-do {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} erledigt",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "You reopened to-do {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} hat die Aufgabe {todo} von der Liste {sourceCalendar} in die Liste {targetCalendar} verschoben",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Sie haben die Aufgabe {todo} von der Liste {sourceCalendar} in die Liste {targetCalendar} verschoben",
    "Calendar, contacts and tasks" : "Kalender, Kontakte und Aufgaben",
    "A <strong>calendar</strong> was modified" : "Ein <strong>Kalender</strong> wurde bearbeitet",
    "A calendar <strong>event</strong> was modified" : "Ein Kalender-<strong>Termin</strong> wurde bearbeitet",
    "A calendar <strong>to-do</strong> was modified" : "Eine Kalender-<strong>Aufgabe</strong> wurde bearbeitet",
    "Contact birthdays" : "Geburtstage von Kontakten",
    "Death of %s" : "Todestag von %s",
    "Untitled calendar" : "Kalender ohne Titel",
    "Calendar:" : "Kalender:",
    "Date:" : "Datum:",
    "Where:" : "Wo:",
    "Description:" : "Beschreibung:",
    "_%n year_::_%n years_" : ["%n Jahr","%n Jahre"],
    "_%n month_::_%n months_" : ["%n Monat","%n Monate"],
    "_%n day_::_%n days_" : ["%n Tag","%n Tage"],
    "_%n hour_::_%n hours_" : ["%n Stunde","%n Stunden"],
    "_%n minute_::_%n minutes_" : ["%n Minute","%n Minuten"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (vor %s)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beschreibung: %s",
    "Where: %s" : "Ort: %s",
    "%1$s via %2$s" : "%1$s über %2$s",
    "In the past on %1$s for the entire day" : "In der Vergangenheit am %1$s für den ganzen Tag",
    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["In einer Minute um %1$s für den ganzen Tag","In %n Minuten um %1$s für den ganzen Tag"],
    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["In einer Stunde um %1$s für den ganzen Tag","In %n Stunden um %1$s für den ganzen Tag"],
    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["In einem Tag am %1$s für den ganzen Tag","In %n Tagen am %1$s für den ganzen Tag"],
    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["In einer Woche am %1$s den ganzen Tag","In %n Wochen am %1$s den ganzen Tag"],
    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["In einem Monat am %1$s den ganzen Tag","In %n Monaten am %1$s den ganzen Tag"],
    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["In einem Jahr am %1$s für den ganzen Tag","In %n Jahren am %1$s für den ganzen Tag"],
    "In the past on %1$s between %2$s - %3$s" : "In der Vergangenheit am %1$s zwischen %2$s - %3$s",
    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["In einer Minute am%1$s zwischen %2$s - %3$s","In %n Minuten am %1$s zwischen %2$s - %3$s"],
    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["In einer Stunde am %1$s zwischen %2$s - %3$s","In %n Stunden am%1$s zwischen %2$s - %3$s"],
    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["In einem Tag am %1$s zwischen %2$s - %3$s","In %n Tagen am %1$szwischen %2$s - %3$s"],
    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["In einer Woche am %1$s zwischen%2$s - %3$s","In %n Wochen am%1$s zwischen %2$s - %3$s"],
    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["In einem Monat am %1$s zwischen %2$s - %3$s","In %n Monaten am %1$s zwischen %2$s - %3$s"],
    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["In einem Jahr am %1$s zwischen %2$s - %3$s","In %n Jahren am%1$s zwischen %2$s - %3$s"],
    "Could not generate when statement" : "Wann-Angabe konnte nicht erzeugt werden",
    "Every Day for the entire day" : "Jeden Tag für den ganzen Tag",
    "Every Day for the entire day until %1$s" : "Jeden Tag für den ganzen Tag bis %1$s",
    "Every Day between %1$s - %2$s" : "Jeden Tag zwischen %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Jeden Tag zwischen %1$s - %2$s bis %3$s",
    "Every %1$d Days for the entire day" : "Alle %1$d Tage für den ganzen Tag",
    "Every %1$d Days for the entire day until %2$s" : "Alle %1$d Tage für den ganzen Tag bis %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Alle %1$d Tage zwischen %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Alle %1$d Tage zwischen %2$s - %3$s bis %4$s",
    "Could not generate event recurrence statement" : "Terminwiederholungsangabe konnte nicht erzeugt werden",
    "Every Week on %1$s for the entire day" : "Jede Woche am %1$s für den ganzen Tag",
    "Every Week on %1$s for the entire day until %2$s" : "Jede Woche am %1$s für den ganzen Tag bis %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Jede Woche am %1$s zwischen %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Jede Woche am %1$s zwischen %2$s - %3$s bis %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Alle %1$d Wochen am %2$s für den ganzen Tag",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Alle %1$d Wochen am %2$s für den ganzen Tag bis %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Alle %1$d Wochen am %2$s zwischen %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Alle %1$d Wochen am %2$s zwischen %3$s - %4$s bis %5$s",
    "Every Month on the %1$s for the entire day" : "Jeden Monat am %1$s für den ganzen Tag",
    "Every Month on the %1$s for the entire day until %2$s" : "Jeden Monat am %1$s für den ganzen Tag bis %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Jeden Monat am %1$s zwischen %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Jeden Monat am %1$s zwischen %2$s - %3$s bis %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Alle %1$d Monate am %2$s für den ganzen Tag",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Alle %1$d Monate am %2$s für den ganzen Tag bis %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Alle %1$d Monate am %2$s zwischen %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Alle %1$d Monate am %2$s zwischen %3$s - %4$s bis %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Jedes Jahr im %1$s am %2$s für den ganzen Tag",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Jedes Jahr im %1$s am %2$s für den ganzen Tag bis %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Jedes Jahr im %1$s am %2$s zwischen %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Jedes Jahr im %1$s am %2$s zwischen %3$s - %4$s bis %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Alle %1$d Jahre im %2$s am %3$s für den ganzen Tag",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Alle %1$d Jahre im %2$s am %3$s für den ganzen Tag bis %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Alle %1$d Jahre im %2$s am %3$s zwischen %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Alle %1$d Jahre im %2$s am %3$s zwischen %4$s - %5$s bis %6$s",
    "On specific dates for the entire day until %1$s" : "An bestimmten Tagen für den ganzen Tag bis %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "An bestimmten Tagen zwischen %1$s - %2$s bis %3$s",
    "In the past on %1$s" : "In der Vergangenheit am %1$s",
    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["In einer Minute am %1$s","In %n Minuten am %1$s"],
    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["In einer Stunde am %1$s","In %n Stunden am %1$s"],
    "_In a day on %1$s_::_In %n days on %1$s_" : ["In einem Tag am %1$s","In %n Tagen am %1$s"],
    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["In einer Woche am %1$s","In %n Wochen am %1$s"],
    "_In a month on %1$s_::_In %n months on %1$s_" : ["In einem Monat am %1$s","In %n Monaten am %1$s"],
    "_In a year on %1$s_::_In %n years on %1$s_" : ["In einem Jahr am %1$s","In %n Jahren am %1$s"],
    "In the past on %1$s then on %2$s" : "In der Vergangenheit am %1$s danach am %2$s",
    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["In einer Minute am %1$s danach am %2$s","In %n Minuten am %1$s danach am %2$s"],
    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["In einer Stunde am %1$s danach am %2$s","In %n Stunden am %1$s danach am %2$s"],
    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["In einem Tag am %1$s danach am %2$s","In %n Tagen am %1$s danach am %2$s"],
    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["In einer Woche am %1$s danach am %2$s","In %n Wochen am %1$s danach am %2$s"],
    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["In einem Monat am %1$s danach am %2$s","In %n Monaten am %1$s danach am %2$s"],
    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["In einem Jahr am %1$s danach am %2$s","In %n Jahren am %1$s danach am %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "In der Vergangenheit am %1$s danach am %2$s und %3$s",
    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["In einer Minute am %1$s danach am %2$s und %3$s","In %n Minuten am %1$s danach am %2$s und %3$s"],
    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["In einer Stunde am %1$s danach am %2$s und %3$s","In %n Stunden am %1$s danach am %2$s und %3$s"],
    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["In einem Tag am %1$s danach am %2$s und %3$s","In %n Tagen am %1$s danach am %2$s und %3$s"],
    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["In einer Woche am %1$s danach am %2$s und %3$s","In %n Wochen am %1$s danach am %2$s und %3$s"],
    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["In einem Monat am %1$s danach am %2$s und %3$s","In %n Monaten am %1$s danach am %2$s und %3$s"],
    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["In einem Jahr am %1$s danach am %2$s und %3$s","In %n Jahren am %1$s danach am %2$s und %3$s"],
    "Could not generate next recurrence statement" : "Nächste Wiederholungsangabe konnte nicht erzeugt werden",
    "Cancelled: %1$s" : "Abgesagt: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" wurde abgesagt.",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s hat Ihre Einladung angenommen",
    "%1$s has tentatively accepted your invitation" : "%1$s hat Ihre Einladung vorläufig angenommen",
    "%1$s has declined your invitation" : "%1$s hat Ihre Einladung abgelehnt",
    "%1$s has responded to your invitation" : "%1$s hat auf Ihre Einladung geantwortet",
    "Invitation updated: %1$s" : "Einladung aktualisiert: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s hat die Veranstaltung \"%2$s\" aktualisiert",
    "Invitation: %1$s" : "Einladung: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s möchte Sie zu \"%2$s\" einladen",
    "Organizer:" : "Organisator:",
    "Attendees:" : "Teilnehmer:",
    "Title:" : "Titel:",
    "When:" : "Wann:",
    "Location:" : "Ort:",
    "Link:" : "Link:",
    "Occurring:" : "Vorkommend:",
    "Accept" : "Akzeptieren",
    "Decline" : "Ablehnen",
    "More options …" : "Weitere Optionen …",
    "More options at %s" : "Weitere Optionen unter %s",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sunday" : "Sonntag",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "März",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "First" : "Erstes",
    "Second" : "Zweites",
    "Third" : "Drittes",
    "Fourth" : "Viertes",
    "Fifth" : "Fünftes",
    "Last" : "Letztes",
    "Second Last" : "Vorletztes",
    "Third Last" : "Drittletztes",
    "Fourth Last" : "Viertletztes",
    "Fifth Last" : "Fünftletztes",
    "Contacts" : "Kontakte",
    "{actor} created address book {addressbook}" : "{actor} hat das Adressbuch {addressbook} erstellt",
    "You created address book {addressbook}" : "Sie haben das Adressbuch {addressbook} erstellt",
    "{actor} deleted address book {addressbook}" : "{actor} hat das Adressbuch {addressbook} gelöscht",
    "You deleted address book {addressbook}" : "Sie haben das Adressbuch {addressbook} gelöscht",
    "{actor} updated address book {addressbook}" : "{actor} hat das Adressbuch {addressbook} aktualisiert",
    "You updated address book {addressbook}" : "Sie haben das Adressbuch {addressbook} aktualisiert",
    "{actor} shared address book {addressbook} with you" : "{actor} hat das Adressbuch {addressbook} mit Ihnen geteilt",
    "You shared address book {addressbook} with {user}" : "Sie haben das Adressbuch {addressbook} mit {user} geteilt",
    "{actor} shared address book {addressbook} with {user}" : "{actor} hat das Adressbuch {addressbook} mit {user} geteilt",
    "{actor} unshared address book {addressbook} from you" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit Ihnen",
    "You unshared address book {addressbook} from {user}" : "Sie teilen das Adressbuch {addressbook} nicht mehr mit {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit Ihnen",
    "You shared address book {addressbook} with group {group}" : "Sie haben das Adressbuch {addressbook} mit der Gruppe {group} geteilt",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} hat das Adressbuch {addressbook} mit der Gruppe {group} geteilt",
    "You unshared address book {addressbook} from group {group}" : "Sie teilen das Adressbuch {addressbook} nicht mehr mit der Gruppe {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit der Gruppe {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} hat den Kontakt {card} im Adressbuch {addressbook} erstellt",
    "You created contact {card} in address book {addressbook}" : "Sie haben den Kontakt {card} im Adressbuch {addressbook} erstellt",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} hat den Kontakt {card} im Adressbuch {addressbook} gelöscht",
    "You deleted contact {card} from address book {addressbook}" : "Sie haben den Kontakt {card} im Adressbuch {addressbook} gelöscht",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} hat den Kontakt {card} im Adressbuch {addressbook} aktualisiert",
    "You updated contact {card} in address book {addressbook}" : "Sie haben den Kontakt {card} im Adressbuch {addressbook} aktualisiert",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Ein <strong>Kontakt</strong> oder ein <strong>Adressbuch</strong> wurde geändert",
    "Accounts" : "Konten",
    "System address book which holds all accounts" : "Systemadressbuch, das alle Konten enthält",
    "File is not updatable: %1$s" : "Datei kann nicht aktualisiert werden: %1$s",
    "Failed to get storage for file" : "Speicherplatz für Datei konnte nicht abgerufen werden",
    "Could not write to final file, canceled by hook" : "Konnte nicht in die endgültige Datei schreiben, wurde durch Hook abgebrochen.",
    "Could not write file contents" : "Dateiinhalt konnte nicht geschrieben werden",
    "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Fehler beim Kopieren der Datei in den Zielspeicherort (kopiert: %1$s, erwartete Dateigröße: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Erwartete Dateigröße von %1$s, aber %2$s gelesen (vom Nextcloud-Client) und geschrieben (in den Nextcloud-Speicher). Dies kann entweder ein Netzwerkproblem auf der sendenden Seite oder ein Problem beim Schreiben in den Speicher auf der Serverseite sein.",
    "Could not rename part file to final file, canceled by hook" : "Konnte Teildatei nicht in endgültige Datei umbenennen, wurde durch Hook abgebrochen.",
    "Could not rename part file to final file" : "Konnte Teildatei nicht in endgültige Datei umbenennen",
    "Failed to check file size: %1$s" : "Dateigröße konnte nicht überprüft werden: %1$s",
    "Could not open file: %1$s, file does seem to exist" : "Datei konnte nicht geöffnet werden: %1$s, Datei scheint zu existieren",
    "Could not open file: %1$s, file doesn't seem to exist" : "Datei konnte nicht geöffnet werden: %1$s, Datei scheint nicht zu existieren",
    "Encryption not ready: %1$s" : "Verschlüsselung nicht bereit: %1$s",
    "Failed to open file: %1$s" : "Datei konnte nicht geöffnet werden: %1$s",
    "Failed to unlink: %1$s" : "Fehler beim Aufheben der Verknüpfung: %1$s",
    "Failed to write file contents: %1$s" : "Fehler beim Schreiben des Dateiinhalts: %1$s",
    "File not found: %1$s" : "Datei nicht gefunden: %1$s",
    "Invalid target path" : "Ungültiger Ziel-Pfad",
    "System is in maintenance mode." : "Das System befindet sich im Wartungsmodus.",
    "Upgrade needed" : "Aktualisierung erforderlich",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ihr %s muss konfiguriert werden, um HTTPS zusammen mit CalDAV und CardDAV unter iOS/macOS nutzen zu können.",
    "Configures a CalDAV account" : "Ein CalDAV-Konto einrichten",
    "Configures a CardDAV account" : "Ein CardDAV-Konto einrichten",
    "Events" : "Ereignisse",
    "Untitled task" : "Unbenannte Aufgabe",
    "Completed on %s" : "Erledigt am %s",
    "Due on %s by %s" : "Fällig am %s von %s",
    "Due on %s" : "Fällig am %s",
    "System Address Book" : "Systemadressbuch",
    "The system address book contains contact information for all users in your instance." : "Das Systemadressbuch enthält Kontaktinformationen für alle Benutzer in dieser Instanz.",
    "Enable System Address Book" : "Systemadressbuch aktivieren",
    "DAV system address book" : "DAV-Systemadressbuch",
    "No outstanding DAV system address book sync." : "Keine ausstehende Synchronisierung des DAV-Systemadressbuchs.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Die Synchronisierung des DAV-Systemadressbuchs wurde noch nicht ausgeführt, da Ihre Instanz mehr als 1000 Benutzer hat oder weil ein Fehler aufgetreten ist. Bitte führen Sie sie manuell aus, indem Sie \"occ dav:sync-system-addressbook\" aufrufen.",
    "WebDAV endpoint" : "WebDAV-Endpunkt",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Es konnte nicht überprüft werden, ob Ihr Webserver ordnungsgemäß eingerichtet ist, um Dateisynchronisation über WebDAV zu ermöglichen. Bitte überprüfen Sie dies manuell.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Ihr Webserver ist noch nicht hinreichend für Datei-Synchronisierung konfiguriert. Die WebDAV-Schnittstelle ist vermutlich defekt.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Ihr Webserver ist ordnungsgemäß eingerichtet um Dateisynchronisation über WebDAV zu ermöglichen.",
    "Migrated calendar (%1$s)" : "Migrierter Kalender (%1$s)",
    "Calendars including events, details and attendees" : "Kalender mit Terminen, Details und Teilnehmern",
    "Contacts and groups" : "Kontakte und Gruppen",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Abwesenheit gespeichert",
    "Failed to save your absence settings" : "Ihre Abwesenheitseinstellungen konnten nicht gespeichert werden",
    "Absence cleared" : "Abwesenheit gelöscht",
    "Failed to clear your absence settings" : "Ihre Abwesenheitseinstellungen konnten nicht gelöscht werden",
    "First day" : "Erster Tag",
    "Last day (inclusive)" : "Letzter Tag (Inklusiv)",
    "Out of office replacement (optional)" : "Abwesenheitsvertretung (optional)",
    "Name of the replacement" : "Name der Vertretung",
    "No results." : "Keine Ergebnisse.",
    "Start typing." : "Anfangen zu tippen.",
    "Short absence status" : "Kurzer Abwesenheitsstatus",
    "Long absence Message" : "Lange Abwesenheitsnachricht",
    "Save" : "Speichern",
    "Disable absence" : "Abwesenheit deaktivieren",
    "Failed to load availability" : "Verfügbarkeit konnte nicht geladen werden",
    "Saved availability" : "Verfügbarkeit gespeichert",
    "Failed to save availability" : "Verfügbarkeit konnte nicht gespeichert werden",
    "Time zone:" : "Zeitzone:",
    "to" : "an",
    "Delete slot" : "Zeitfenster löschen",
    "No working hours set" : "Keine Arbeitszeiten konfiguriert",
    "Add slot" : "Zeitfenster hinzufügen",
    "Weekdays" : "Wochentage",
    "Pick a start time for {dayName}" : "Eine Startzeit für {dayName} wählen",
    "Pick a end time for {dayName}" : "Eine Endezeit für {dayName} wählen",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Setzen Sie den Benutzerstatus außerhalb Ihrer Verfügbarkeit automatisch auf \"Nicht stören\", um alle Benachrichtigungen stumm zu schalten.",
    "Availability" : "Verfügbarkeit",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Wenn Sie Ihre Arbeitszeiten angeben, können andere beim Buchen einer Besprechung sehen, wann Sie nicht im Büro sind.",
    "Absence" : "Abwesenheit",
    "Configure your next absence period." : "Richten Sie ihren nächsten Abwesenheitszeitraum ein.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installieren Sie außerdem die {calendarappstoreopen}Kalender-App{linkclose} oder {calendardocopen}verbinden Sie Ihren Desktop & Mobilgerät zur Synchronisierung ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bitte stellen Sie sicher, dass Sie {emailopen}den E-Mail Server{linkclose} ordnungsgemäß eingerichtet haben.",
    "Calendar server" : "Kalender-Server",
    "Send invitations to attendees" : "Einladungen an die Teilnehmer versenden",
    "Automatically generate a birthday calendar" : "Automatisch einen Kalender für Geburtstage erstellen",
    "Birthday calendars will be generated by a background job." : "Kalender für Geburtstage werden von einem Hintergrund-Auftrag erstellt",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Die Einträge werden nicht sofort angezeigt. Nach der Aktivierung wird es ein wenig dauern bis zur Anzeige.",
    "Send notifications for events" : "Sende Benachrichtigungen für Termine",
    "Notifications are sent via background jobs, so these must occur often enough." : "Benachrichtigungen werden von Hintergrundjobs versendet, so dass diese häufig genug ausgeführt werden müssen.",
    "Send reminder notifications to calendar sharees as well" : "Erinnerungsbenachrichtigungen auch an die Kalenderfreigaben senden",
    "Reminders are always sent to organizers and attendees." : "Erinnerungen werden immer an Organisatoren und Teilnehmer gesendet.",
    "Enable notifications for events via push" : "Benachrichtigungen für Termine per Push aktivieren",
    "Cancel" : "Abbrechen",
    "Import" : "Importieren",
    "Error while saving settings" : "Fehler beim Speichern der Einstellungen",
    "Contact reset successfully" : "Kontakt zurückgesetzt",
    "Error while resetting contact" : "Fehler beim Zurücksetzen des Kontakts",
    "Contact imported successfully" : "Kontakt importiert",
    "Error while importing contact" : "Fehler beim Import des Kontakts",
    "Example Content" : "Beispielinhalt",
    "Set example content to be created on new user first login." : "Beispielinhalte festlegen, die bei der ersten Anmeldung eines neuen Benutzers erstellt werden sollen.",
    "Import contact" : "Kontakt importieren",
    "Reset to default contact" : "Standardkontakt zurücksetzen",
    "Import contacts" : "Kontakte importieren",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Durch das Importieren einer neuen VCF-Datei wird der vorhandene Standardkontakt gelöscht und durch den neuen ersetzt. Fortsetzen?",
    "There was an error updating your attendance status." : "Es ist ein Fehler beim Aktualisieren Ihres Teilnehmerstatus aufgetreten.",
    "Please contact the organizer directly." : "Bitte den Organisator direkt kontaktieren.",
    "Are you accepting the invitation?" : "Die Einladung annehmen?",
    "Tentative" : "Vorläufig",
    "Your attendance was updated successfully." : "Ihr Teilnehmerstatus wurde aktualisiert.",
    "Time:" : "Zeit:",
    "Could not open file" : "Datei konnte nicht geöffnet werden",
    "Invalid chunk name" : "Ungültiger Chunk-Name",
    "Could not rename part file assembled from chunks" : "Aus Chunks zusammengesetzte Teildatei konnte nicht umbenannt werden"
},
"nplurals=2; plural=(n != 1);");
